# REPLICATION: RELIABILITY ANALYSIS

# Load required packages ----
require(readxl)
require(icr)

# Load main dataset

dataset <- readRDS("dataset_wide.rds")

# Prepare hand- and automatically-coded data ----

hand_coding_table_paths <- c("hand_coding_c1.xlsx",
                             "hand_coding_c2.xlsx",
                             "hand_coding_c3.xlsx",
                             "hand_coding_c4.xlsx")

id_table <- readxl::read_xlsx("hand_coding_id_table.xlsx")

hand_coded_samples <- readxl::read_xlsx(hand_coding_table_paths[1], col_types = c("text"))[0,]

for (i in 1:NROW(hand_coding_table_paths)){
    tab <- readxl::read_xlsx(hand_coding_table_paths[i], col_types = c("text"))
    tab$coder_tab <- i
    hand_coded_samples <- dplyr::bind_rows(hand_coded_samples, tab)
}

hand_coded_samples <- utils::type.convert(hand_coded_samples, as.is=TRUE)
hand_coded_samples$doc_proposal_ref_enacting <- hand_coded_samples$doc_proposal_ref_int_enacting + hand_coded_samples$doc_proposal_ref_ext_enacting

dataset$doc_proposal_ref_enacting <- dataset$doc_proposal_ref_int_enacting + dataset$doc_proposal_ref_ext_enacting


# Human - Machine ICR ----

hand_coded_samples <- hand_coded_samples[!duplicated(hand_coded_samples$ID),] # remove duplicate IDs
hand_coded_samples <- hand_coded_samples[order(hand_coded_samples$ID),] # sort

# merge id_table and dataset
machine_coded_samples <- merge(id_table[, c("ID", "procedure_id", "coder", "url")], dataset, by = "procedure_id", all.x=TRUE)

machine_coded_samples <- machine_coded_samples[,names(machine_coded_samples) %in% names (hand_coded_samples)]

coded_varnames <- grep("doc_proposal_[a-z](?!omm)", names(hand_coded_samples), value= TRUE, perl=TRUE)

results <- list()

metrics <- c("nominal", "ordinal", "interval")

# Function to perform ICR over all variables for a specified metric
reliablity_analysis <- function(metric="nominal"){

    results <- list()
    coded_varnames <- grep("doc_proposal_[a-z](?!omm)", names(hand_coded_samples), value= TRUE, perl=TRUE)


    for (j in 1:NROW(coded_varnames)){
        coded_var <- coded_varnames[j]
        # merge hand and machine obs for var
        hand_var <- hand_coded_samples[,c("ID", coded_var)]
        names(hand_var)[2] <- "hand"
        machine_var <- machine_coded_samples[,c("ID", coded_var)]
        names(machine_var)[2] <- "machine"
        hand_machine_var_df <- merge(hand_var, machine_var)
        hand_machine_var_df <- hand_machine_var_df[complete.cases(hand_machine_var_df),] # remove NAs
        results[[coded_var]][["coded_matrix"]]<- t(dplyr::select(hand_machine_var_df, -c("ID")))
        results[[coded_var]][["kripp"]] <- icr::krippalpha(results[[coded_var]][["coded_matrix"]], metric =  metric, bootstrap = TRUE, bootnp=TRUE)

        # difference table
        hand_machine_var_df$diff <- hand_machine_var_df[,2] - hand_machine_var_df[,3]

        results[[coded_var]][["diff"]] <- hand_machine_var_df

    }

    return(results)
}


# Write results to dataframe (Table B2) ----

df_reliability <- data.frame()

for (l in 1:NROW(metrics)){


    results <- reliablity_analysis(metrics[l])

    # For all variables
    for (k in 1:NROW(coded_varnames)){
        row <- c()

        coded_var <- coded_varnames[k]

        row['var'] <- coded_var
        row['metric'] <- metrics[l]

        boots_cis <- quantile(results[[coded_var]][["kripp"]]$bootstraps, probs=c(0.025,0.975))
        kripp_a <- results[[coded_var]][["kripp"]]$alpha

        row['lo']<-boots_cis[[1]]
        row['mean']<-kripp_a

        row['up']<-boots_cis[[2]]

        # store results in dataframe
        df_reliability <- dplyr::bind_rows(df_reliability, row)

    }

}

